==> jupyterlab_mutableai-0.1.10.tgz: package/lib/manager.js <==
import { MainMenu } from '@jupyterlab/mainmenu';
import { nullTranslator } from '@jupyterlab/translation';
import { InputDialog } from '@jupyterlab/apputils';
import { PromiseDelegate } from '@lumino/coreutils';
import { toggleFlag, updateSettings } from './commands';
import { fastForwardIcon, documentIcon, customDocIcon, refactorIcon } from './icons';
import { context_custom, context_documentation, context_refactor, context_fast_forward } from './commands';
import { ToolbarManager } from './toolbarManager';
import { requestAPI } from './handler';
var mode;
(function (mode) {
    mode["FULL"] = "FULL";
    mode["DOCUMENT"] = "DOCUMENT";
    mode["FREE"] = "FREE";
    mode["REFACTOR"] = "REFACTOR";
})(mode || (mode = {}));
export class MutableAIManager {
    constructor(options) {
        var _a;
        this._ready = new PromiseDelegate();
        this._mutableAI = null;
        this.mutableAiMainMenu = null;
        this._translator = (_a = options.translator) !== null && _a !== void 0 ? _a : nullTranslator;
        this._mainMenu = options.mainMenu;
        this._commands = options.commands;
        this._contextMenu = options.contextMenu;
        this._factory = options.factory;
        this._processFilePointer = null;
        this.onLunchToProduction = this.onLunchToProduction.bind(this);
        this.onDocToProduction = this.onDocToProduction.bind(this);
        this.onCustomCommand = this.onCustomCommand.bind(this);
        this.onRefactorToProduction = this.onRefactorToProduction.bind(this);
        this.pollingCallback = this.pollingCallback.bind(this);
        this._toolbarManager = new ToolbarManager({
            docRegistry: options.docRegistry,
            handlers: {
                onLunchToProduction: this.onLunchToProduction,
                onDocToProduction: this.onDocToProduction,
                onCustomCommand: this.onCustomCommand,
                onRefactorToProduction: this.onRefactorToProduction
            },
            trans: options.translator
        });
        options
            .getSettings()
            .then(mutableAI => {
            this._mutableAI = mutableAI;
            this._mutableAI.changed.connect(this._mutableAISettingsChanged, this);
            this._mutableAISettingsChanged();
            this._ready.resolve();
        })
            .catch(reason => {
            console.warn(reason);
            this._ready.reject(reason);
        });
        this._transformPollingManager = options.transformPollingManager;
    }
    /*
      Mutable AI manager extension enable port.
    */
    enable() {
        var _a;
        (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.set('enabled', true);
    }
    /*
      Mutable AI manager extension disable port.
    */
    disable() {
        var _a;
        (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.set('enabled', false);
    }
    pollingCallback(id, filename, dirname) {
        this._transformPollingManager.startPolling(id, filename, dirname);
    }
    handleLunchToProductionCall(name, callback) {
        var _a, _b;
        const apiKey = (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.get('apiKey').composite;
        const transformDomain = (_b = this._mutableAI) === null || _b === void 0 ? void 0 : _b.get('transformDomain').composite;
        const dataToSend = { name, apiKey, transformDomain, mode: mode.FULL };
        const reply = requestAPI('TRANSFORM_NB', {
            body: JSON.stringify(dataToSend),
            method: 'POST'
        });
        reply
            .then((response) => {
            console.log('Transformed in progress!');
            callback(response.uid, name, response.dirname);
        })
            .catch(e => console.log('Transformation failed!', e));
    }
    onLunchToProduction(context) {
        const name = context.path;
        this.handleLunchToProductionCall(name, this.pollingCallback);
    }
    handleDocToProductionCall(name, callback) {
        var _a, _b;
        const apiKey = (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.get('apiKey').composite;
        const transformDomain = (_b = this._mutableAI) === null || _b === void 0 ? void 0 : _b.get('transformDomain').composite;
        const dataToSend = { name, apiKey, transformDomain, mode: mode.DOCUMENT };
        const reply = requestAPI('TRANSFORM_NB', {
            body: JSON.stringify(dataToSend),
            method: 'POST'
        });
        reply
            .then((response) => {
            console.log('Transformed in progress!');
            callback(response.uid, name, response.dirname);
        })
            .catch(e => console.log('Transformation failed!', e));
    }
    onRefactorToProduction(context) {
        const name = context.path;
        this.handleRefactorToProductionCall(name, this.pollingCallback);
    }
    handleRefactorToProductionCall(name, callback) {
        var _a, _b;
        const apiKey = (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.get('apiKey').composite;
        const transformDomain = (_b = this._mutableAI) === null || _b === void 0 ? void 0 : _b.get('transformDomain').composite;
        const dataToSend = { name, apiKey, transformDomain, mode: mode.REFACTOR };
        const reply = requestAPI('TRANSFORM_NB', {
            body: JSON.stringify(dataToSend),
            method: 'POST'
        });
        reply
            .then((response) => {
            console.log('Transformed in progress!');
            callback(response.uid, name, response.dirname);
        })
            .catch(e => console.log('Transformation failed!', e));
    }
    onDocToProduction(context) {
        const name = context.path;
        this.handleDocToProductionCall(name, this.pollingCallback);
    }
    async handleCustomCommandCall(name, callback) {
        var _a, _b;
        // Prompt the user about the statement to be executed
        const input = await InputDialog.getText({
            title: 'Mutable AI Custom Command',
            okLabel: 'Execute',
            placeholder: 'Custom Commands'
        });
        // Execute the statement
        if (input.button.accept) {
            const commands = input.value;
            const apiKey = (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.get('apiKey').composite;
            const transformDomain = (_b = this._mutableAI) === null || _b === void 0 ? void 0 : _b.get('transformDomain').composite;
            const dataToSend = {
                name,
                apiKey,
                transformDomain,
                instruction: commands,
                mode: mode.FREE
            };
            const reply = requestAPI('TRANSFORM_NB', {
                body: JSON.stringify(dataToSend),
                method: 'POST'
            });
            reply
                .then((response) => {
                console.log('Transformed in progress!');
                callback(response.uid, name, response.dirname);
            })
                .catch(e => console.log('Transformation failed!', e));
        }
    }
    onCustomCommand(context) {
        const name = context.path;
        this.handleCustomCommandCall(name, this.pollingCallback);
    }
    createContextMenu() {
        /*
          Mutable AI update settings in main menu command.
        */
        this._forwardRef = this._commands.addCommand(context_fast_forward, {
            label: `Fast forward to production`,
            icon: fastForwardIcon,
            execute: () => {
                var _a;
                const file = (_a = this._factory.tracker.currentWidget) === null || _a === void 0 ? void 0 : _a.selectedItems().next();
                if (file === null || file === void 0 ? void 0 : file.path) {
                    this.handleLunchToProductionCall(file.path, this.pollingCallback);
                }
            }
        });
        this._docRef = this._commands.addCommand(context_documentation, {
            label: 'Document all methods',
            icon: documentIcon,
            execute: () => {
                var _a;
                const file = (_a = this._factory.tracker.currentWidget) === null || _a === void 0 ? void 0 : _a.selectedItems().next();
                if (file === null || file === void 0 ? void 0 : file.path) {
                    this.handleDocToProductionCall(file.path, this.pollingCallback);
                }
            }
        });
        this._refactorRef = this._commands.addCommand(context_refactor, {
            label: 'Refactor file',
            icon: refactorIcon,
            execute: () => {
                var _a;
                const file = (_a = this._factory.tracker.currentWidget) === null || _a === void 0 ? void 0 : _a.selectedItems().next();
                if (file === null || file === void 0 ? void 0 : file.path) {
                    this.handleRefactorToProductionCall(file.path, this.pollingCallback);
                }
            }
        });
        this._customRef = this._commands.addCommand(context_custom, {
            label: 'Custom command',
            icon: customDocIcon,
            execute: () => {
                var _a;
                const file = (_a = this._factory.tracker.currentWidget) === null || _a === void 0 ? void 0 : _a.selectedItems().next();
                if (file === null || file === void 0 ? void 0 : file.path) {
                    this.handleCustomCommandCall(file.path, this.pollingCallback);
                }
            }
        });
    }
    /*
      Mutable AI manager extension initialization.
    */
    initializePlugin() {
        var _a;
        this.dispose();
        const enabled = (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.get('enabled').composite;
        if (enabled) {
            this._toolbarManager.initialize();
            this.createContextMenu();
            const trans = this._translator.load('jupyterlab');
            this.mutableAiMainMenu = MainMenu.generateMenu(this._commands, {
                id: 'mutable-ai-settings',
                label: 'Mutable AI Settings',
                rank: 80
            }, trans);
            this.mutableAiMainMenu.addGroup([
                {
                    command: toggleFlag
                },
                {
                    command: updateSettings
                }
            ]);
            this._mainMenu.addMenu(this.mutableAiMainMenu, { rank: 80 });
            this._processFilePointer = this._contextMenu.addItem({
                command: 'context_menu:open',
                selector: '.jp-DirListing-item[data-file-type="notebook"]',
                rank: 0
            });
        }
    }
    /*
      Mutable AI manager extension dispose.
    */
    dispose() {
        var _a, _b, _c, _d, _e, _f;
        (_a = this.mutableAiMainMenu) === null || _a === void 0 ? void 0 : _a.dispose();
        (_b = this._processFilePointer) === null || _b === void 0 ? void 0 : _b.dispose();
        this._toolbarManager.dispose();
        (_c = this._forwardRef) === null || _c === void 0 ? void 0 : _c.dispose();
        (_d = this._docRef) === null || _d === void 0 ? void 0 : _d.dispose();
        (_e = this._customRef) === null || _e === void 0 ? void 0 : _e.dispose();
        (_f = this._refactorRef) === null || _f === void 0 ? void 0 : _f.dispose();
    }
    /**
     * A promise that resolves when the settings have been loaded.
     */
    get ready() {
        return this._ready.promise;
    }
    /**
     * Mutable AI manager change extension according to settings.
     */
    _mutableAISettingsChanged() {
        var _a;
        const enabled = (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.get('enabled').composite;
        if (enabled) {
            this.initializePlugin();
        }
        else {
            this.dispose();
        }
    }
}

==> jupyterlab_mutableai-0.1.16.tgz: package/lib/manager.js <==
import { MainMenu } from '@jupyterlab/mainmenu';
import { nullTranslator } from '@jupyterlab/translation';
import { InputDialog } from '@jupyterlab/apputils';
import { PromiseDelegate } from '@lumino/coreutils';
import { toggleFlag, updateSettings } from './commands';
import { fastForwardIcon, documentIcon, customDocIcon, refactorIcon } from './icons';
import { context_custom, context_documentation, context_refactor, context_fast_forward } from './commands';
import { ToolbarManager } from './toolbarManager';
import { requestAPI } from './handler';
var mode;
(function (mode) {
    mode["FULL"] = "FULL";
    mode["DOCUMENT"] = "DOCUMENT";
    mode["FREE"] = "FREE";
    mode["REFACTOR"] = "REFACTOR";
})(mode || (mode = {}));
export class MutableAIManager {
    constructor(options) {
        var _a;
        this._ready = new PromiseDelegate();
        this._mutableAI = null;
        this.mutableAiMainMenu = null;
        this._translator = (_a = options.translator) !== null && _a !== void 0 ? _a : nullTranslator;
        this._mainMenu = options.mainMenu;
        this._commands = options.commands;
        this._contextMenu = options.contextMenu;
        this._factory = options.factory;
        this._processFilePointer = null;
        this.onLunchToProduction = this.onLunchToProduction.bind(this);
        this.onDocToProduction = this.onDocToProduction.bind(this);
        this.onCustomCommand = this.onCustomCommand.bind(this);
        this.onRefactorToProduction = this.onRefactorToProduction.bind(this);
        this.pollingCallback = this.pollingCallback.bind(this);
        this._toolbarManager = new ToolbarManager({
            docRegistry: options.docRegistry,
            handlers: {
                onLunchToProduction: this.onLunchToProduction,
                onDocToProduction: this.onDocToProduction,
                onCustomCommand: this.onCustomCommand,
                onRefactorToProduction: this.onRefactorToProduction
            },
            trans: options.translator
        });
        options
            .getSettings()
            .then(mutableAI => {
            this._mutableAI = mutableAI;
            this._mutableAI.changed.connect(this._mutableAISettingsChanged, this);
            this._mutableAISettingsChanged();
            this._ready.resolve();
        })
            .catch(reason => {
            console.warn(reason);
            this._ready.reject(reason);
        });
        this._transformPollingManager = options.transformPollingManager;
    }
    /*
      Mutable AI manager extension enable port.
    */
    enable() {
        var _a;
        (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.set('enabled', true);
    }
    /*
      Mutable AI manager extension disable port.
    */
    disable() {
        var _a;
        (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.set('enabled', false);
    }
    pollingCallback(file_path, current_file_path) {
        this._transformPollingManager.startPolling(file_path, current_file_path);
    }
    handleLunchToProductionCall(name, callback) {
        var _a, _b;
        const apiKey = (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.get('apiKey').composite;
        const transformDomain = (_b = this._mutableAI) === null || _b === void 0 ? void 0 : _b.get('transformDomain').composite;
        const dataToSend = { name, apiKey, transformDomain, mode: mode.FULL };
        const reply = requestAPI('TRANSFORM_NB', {
            body: JSON.stringify(dataToSend),
            method: 'POST'
        });
        reply
            .then((response) => {
            console.log('Transformed in progress!');
            callback(response.file_path, name);
        })
            .catch(e => console.log('Transformation failed!', e));
    }
    onLunchToProduction(context) {
        const name = context.path;
        this.handleLunchToProductionCall(name, this.pollingCallback);
    }
    handleDocToProductionCall(name, callback) {
        var _a, _b;
        const apiKey = (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.get('apiKey').composite;
        const transformDomain = (_b = this._mutableAI) === null || _b === void 0 ? void 0 : _b.get('transformDomain').composite;
        const dataToSend = { name, apiKey, transformDomain, mode: mode.DOCUMENT };
        const reply = requestAPI('TRANSFORM_NB', {
            body: JSON.stringify(dataToSend),
            method: 'POST'
        });
        reply
            .then((response) => {
            console.log('Transformed in progress!');
            callback(response.file_path, name);
        })
            .catch(e => console.log('Transformation failed!', e));
    }
    onRefactorToProduction(context) {
        const name = context.path;
        this.handleRefactorToProductionCall(name, this.pollingCallback);
    }
    handleRefactorToProductionCall(name, callback) {
        var _a, _b;
        const apiKey = (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.get('apiKey').composite;
        const transformDomain = (_b = this._mutableAI) === null || _b === void 0 ? void 0 : _b.get('transformDomain').composite;
        const dataToSend = { name, apiKey, transformDomain, mode: mode.REFACTOR };
        const reply = requestAPI('TRANSFORM_NB', {
            body: JSON.stringify(dataToSend),
            method: 'POST'
        });
        reply
            .then((response) => {
            console.log('Transformed in progress!');
            callback(response.file_path, name);
        })
            .catch(e => console.log('Transformation failed!', e));
    }
    onDocToProduction(context) {
        const name = context.path;
        this.handleDocToProductionCall(name, this.pollingCallback);
    }
    async handleCustomCommandCall(name, callback) {
        var _a, _b;
        // Prompt the user about the statement to be executed
        const input = await InputDialog.getText({
            title: 'Mutable AI Custom Command',
            okLabel: 'Execute',
            placeholder: 'Custom Commands'
        });
        // Execute the statement
        if (input.button.accept) {
            const commands = input.value;
            const apiKey = (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.get('apiKey').composite;
            const transformDomain = (_b = this._mutableAI) === null || _b === void 0 ? void 0 : _b.get('transformDomain').composite;
            const dataToSend = {
                name,
                apiKey,
                transformDomain,
                instruction: commands,
                mode: mode.FREE
            };
            const reply = requestAPI('TRANSFORM_NB', {
                body: JSON.stringify(dataToSend),
                method: 'POST'
            });
            reply
                .then((response) => {
                console.log('Transformed in progress!');
                callback(response.file_path, name);
            })
                .catch(e => console.log('Transformation failed!', e));
        }
    }
    onCustomCommand(context) {
        const name = context.path;
        this.handleCustomCommandCall(name, this.pollingCallback);
    }
    createContextMenu() {
        /*
          Mutable AI update settings in main menu command.
        */
        this._forwardRef = this._commands.addCommand(context_fast_forward, {
            label: `Fast forward to production`,
            icon: fastForwardIcon,
            execute: () => {
                var _a;
                const file = (_a = this._factory.tracker.currentWidget) === null || _a === void 0 ? void 0 : _a.selectedItems().next();
                if (file === null || file === void 0 ? void 0 : file.path) {
                    this.handleLunchToProductionCall(file.path, this.pollingCallback);
                }
            }
        });
        this._docRef = this._commands.addCommand(context_documentation, {
            label: 'Document all methods',
            icon: documentIcon,
            execute: () => {
                var _a;
                const file = (_a = this._factory.tracker.currentWidget) === null || _a === void 0 ? void 0 : _a.selectedItems().next();
                if (file === null || file === void 0 ? void 0 : file.path) {
                    this.handleDocToProductionCall(file.path, this.pollingCallback);
                }
            }
        });
        this._refactorRef = this._commands.addCommand(context_refactor, {
            label: 'Refactor file',
            icon: refactorIcon,
            execute: () => {
                var _a;
                const file = (_a = this._factory.tracker.currentWidget) === null || _a === void 0 ? void 0 : _a.selectedItems().next();
                if (file === null || file === void 0 ? void 0 : file.path) {
                    this.handleRefactorToProductionCall(file.path, this.pollingCallback);
                }
            }
        });
        this._customRef = this._commands.addCommand(context_custom, {
            label: 'Custom command',
            icon: customDocIcon,
            execute: () => {
                var _a;
                const file = (_a = this._factory.tracker.currentWidget) === null || _a === void 0 ? void 0 : _a.selectedItems().next();
                if (file === null || file === void 0 ? void 0 : file.path) {
                    this.handleCustomCommandCall(file.path, this.pollingCallback);
                }
            }
        });
    }
    /*
      Mutable AI manager extension initialization.
    */
    initializePlugin() {
        var _a;
        this.dispose();
        const enabled = (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.get('enabled').composite;
        if (enabled) {
            this._toolbarManager.initialize();
            this.createContextMenu();
            const trans = this._translator.load('jupyterlab');
            this.mutableAiMainMenu = MainMenu.generateMenu(this._commands, {
                id: 'mutable-ai-settings',
                label: 'Mutable AI Settings',
                rank: 80
            }, trans);
            this.mutableAiMainMenu.addGroup([
                {
                    command: toggleFlag
                },
                {
                    command: updateSettings
                }
            ]);
            this._mainMenu.addMenu(this.mutableAiMainMenu, { rank: 80 });
            this._processFilePointer = this._contextMenu.addItem({
                command: 'context_menu:open',
                selector: '.jp-DirListing-item[data-file-type="notebook"]',
                rank: 0
            });
        }
    }
    /*
      Mutable AI manager extension dispose.
    */
    dispose() {
        var _a, _b, _c, _d, _e, _f;
        (_a = this.mutableAiMainMenu) === null || _a === void 0 ? void 0 : _a.dispose();
        (_b = this._processFilePointer) === null || _b === void 0 ? void 0 : _b.dispose();
        this._toolbarManager.dispose();
        (_c = this._forwardRef) === null || _c === void 0 ? void 0 : _c.dispose();
        (_d = this._docRef) === null || _d === void 0 ? void 0 : _d.dispose();
        (_e = this._customRef) === null || _e === void 0 ? void 0 : _e.dispose();
        (_f = this._refactorRef) === null || _f === void 0 ? void 0 : _f.dispose();
    }
    /**
     * A promise that resolves when the settings have been loaded.
     */
    get ready() {
        return this._ready.promise;
    }
    /**
     * Mutable AI manager change extension according to settings.
     */
    _mutableAISettingsChanged() {
        var _a;
        const enabled = (_a = this._mutableAI) === null || _a === void 0 ? void 0 : _a.get('enabled').composite;
        if (enabled) {
            this.initializePlugin();
        }
        else {
            this.dispose();
        }
    }
}
